diff --git a/test/unit/angular/service/popup.unit.js b/test/unit/angular/service/popup.unit.js
index 9e306fb24f..718842a145 100644
--- a/test/unit/angular/service/popup.unit.js
+++ b/test/unit/angular/service/popup.unit.js
@@ -55,7 +55,7 @@ describe('$ionicPopup service', function() {
it('should set the specified custom CSS class to popup container', function() {
var popup = TestUtil.unwrapPromise($ionicPopup._createPopup({
template: 'Hello, friend!',
- class: 'mycustomclass'
+ cssClass: 'mycustomclass'
}));
expect(popup.element.hasClass('mycustomclass')).toBe(true);
});
diff --git a/js/angular/service/popup.js b/js/angular/service/popup.js
index 1f98b44cd1..0d93e72a29 100644
--- a/js/angular/service/popup.js
+++ b/js/angular/service/popup.js
@@ -1,6 +1,6 @@
var POPUP_TPL =
- '
' +
+ '
' +
'
' +
'
' +
'' +
@@ -138,7 +138,7 @@ function($ionicTemplateLoader, $ionicBackdrop, $q, $timeout, $rootScope, $ionicB
* ```
* {
* title: '', // String. The title of the popup.
* class: '', // String, The custom CSS class name
* subTitle: '', // String (optional). The sub-title of the popup.
* template: '', // String (optional). The html template to place in the popup body.
* templateUrl: '', // String (optional). The URL of an html template to place in the popup body.
@@ -177,7 +177,7 @@ function($ionicTemplateLoader, $ionicBackdrop, $q, $timeout, $rootScope, $ionicB
* ```
* {
* title: '', // String. The title of the popup.
* class: '', // String, The custom CSS class name
* subTitle: '', // String (optional). The sub-title of the popup.
* template: '', // String (optional). The html template to place in the popup body.
* templateUrl: '', // String (optional). The URL of an html template to place in the popup body.
@@ -206,7 +206,7 @@ function($ionicTemplateLoader, $ionicBackdrop, $q, $timeout, $rootScope, $ionicB
* ```
* {
* title: '', // String. The title of the popup.
* class: '', // String, The custom CSS class name
* subTitle: '', // String (optional). The sub-title of the popup.
* template: '', // String (optional). The html template to place in the popup body.
* templateUrl: '', // String (optional). The URL of an html template to place in the popup body.
@@ -245,7 +245,7 @@ function($ionicTemplateLoader, $ionicBackdrop, $q, $timeout, $rootScope, $ionicB
* ```
* {
* title: '', // String. The title of the popup.
* class: '', // String, The custom CSS class name
* subTitle: '', // String (optional). The sub-title of the popup.
* template: '', // String (optional). The html template to place in the popup body.
* templateUrl: '', // String (optional). The URL of an html template to place in the popup body.
@@ -310,7 +310,7 @@ function($ionicTemplateLoader, $ionicBackdrop, $q, $timeout, $rootScope, $ionicB
title: options.title,
buttons: options.buttons,
subTitle: options.subTitle,
- class: options.class,
+ cssClass: options.cssClass,
$buttonTapped: function(button, event) {
var result = (button.onTap || angular.noop)(event);
event = event.originalEvent || event; //jquery events
@@ -138,7 +138,7 @@ function($ionicTemplateLoader, $ionicBackdrop, $q, $timeout, $rootScope, $ionicB
* {
* title: '', // String. The title of the popup.
- * class: '', // String, The custom CSS class name
+ * cssClass: '', // String, The custom CSS class name
* subTitle: '', // String (optional). The sub-title of the popup.
* template: '', // String (optional). The html template to place in the popup body.
@@ -177,7 +177,7 @@ function($ionicTemplateLoader, $ionicBackdrop, $q, $timeout, $rootScope, $ionicB
* {
* title: '', // String. The title of the popup.
- * class: '', // String, The custom CSS class name
+ * cssClass: '', // String, The custom CSS class name
* subTitle: '', // String (optional). The sub-title of the popup.
* template: '', // String (optional). The html template to place in the popup body.
@@ -206,7 +206,7 @@ function($ionicTemplateLoader, $ionicBackdrop, $q, $timeout, $rootScope, $ionicB
* {
* title: '', // String. The title of the popup.
- * class: '', // String, The custom CSS class name
+ * cssClass: '', // String, The custom CSS class name
* subTitle: '', // String (optional). The sub-title of the popup.
* template: '', // String (optional). The html template to place in the popup body.
@@ -245,7 +245,7 @@ function($ionicTemplateLoader, $ionicBackdrop, $q, $timeout, $rootScope, $ionicB
* {
* title: '', // String. The title of the popup.
- * class: '', // String, The custom CSS class name
+ * cssClass: '', // String, The custom CSS class name
* subTitle: '', // String (optional). The sub-title of the popup.
* template: '', // String (optional). The html template to place in the popup body.